@@ -50,6 +50,15 @@ fn test_arr() {
     assert_eq!(test[1], 2);
 }
 
+#[test]
+fn test_copy() {
+    let test = arr![u32; 1, 2, 3];
+    let test2 = test;
+    // if GenericArray is not copy, this should fail as a use of a moved value
+    assert_eq!(test[1], 2);
+    assert_eq!(test2[0], 1);
+}
+
 #[test]
 fn test_iter_flat_map() {
     assert!((0..5).flat_map(|i| arr![i32; 2 * i, 2 * i + 1]).eq(0..10));
@@ -66,7 +75,7 @@ mod impl_serde {
     fn test_serde_implementation() {
         let array: GenericArray<f64, U6> = arr![f64; 0.0, 5.0, 3.0, 7.07192, 76.0, -9.0];
         let string = serde_json::to_string(&array).unwrap();
-        assert_eq!(string, "[0,5,3,7.07192,76,-9]");
+        assert_eq!(string, "[0.0,5.0,3.0,7.07192,76.0,-9.0]");
 
         let test_array: GenericArray<f64, U6> = serde_json::from_str(&string).unwrap();
         assert_eq!(test_array, array);
